@@ -1,9 +1,12 @@
+#include <QNetworkRequest>
+#include <QUrl>
+
 #include "QvkVersion.h"
 #include "global.h"
 
 QvkVersion::QvkVersion()
 {
-    connect( &manager, SIGNAL( finished( QNetworkReply* ) ), SLOT( slot_downloadFinished( QNetworkReply* ) ) );
+    connect( &manager, SIGNAL( finished(QNetworkReply*) ), SLOT( slot_downloadFinished(QNetworkReply*) ) );
 }
 
 
