@@ -245,6 +245,9 @@ void QvkRegionChoise_wl::mousePressEvent( QMouseEvent *event )
 
     clearMask();
     repaint();
+
+    // Siehe Hinweis in mouseReleaseEvent
+    resize( width()-1, height()-1 );
 }
 
 
@@ -265,8 +268,9 @@ void QvkRegionChoise_wl::mouseReleaseEvent( QMouseEvent * event )
     // setVisible( false );
     // setVisible( true );
 
-    // Oder ein resize, das Fenster flackert nicht bzw. zeigt keine Anzeichen einer Animation.
-    resize( width()-1, height()-1 );
+    // Oder ein resize, das Fenster flackert nicht bzw. zeigt keine Anzeichen einer Animation,
+    // wie bei setVisible(false/true)
+    resize( width()+1, height()+1 );
 }
 
 
@@ -1027,10 +1031,6 @@ void QvkRegionChoise_wl::HandleTopLeftSize( QPainter &painter)
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-/*    painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( frame_X + framePenHalf + 1 ) +
-                                                "\n" +
-                                                "y:" + QString::number( frame_Y + framePenHalf + 1 ) );
-*/
     painter.drawText( rect, Qt::AlignCenter, "x:" + QString::number( static_cast<int>(( frame_X + framePenHalf ) * devicePixelRatio()) ) +
                                              "\n" +
                                              "y:" + QString::number( static_cast<int>(( frame_Y + framePenHalf ) * devicePixelRatio()) ) );
@@ -1082,9 +1082,7 @@ void QvkRegionChoise_wl::HandleTopMiddleSize( QPainter &painter )
     painter.setBrush( QBrush( HandleColorBackgroundSize, Qt::SolidPattern ) );
     painter.setPen( QPen( Qt::black, 2 ) );
     painter.drawRoundedRect( rect, 5, 5 );
-//    painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( frame_Y + framePenHalf + 1 ) );
     painter.drawText( rect, Qt::AlignCenter, "y:" + QString::number( static_cast<int>(( frame_Y + framePenHalf ) * devicePixelRatio()) ) );
-
 }
 
 
@@ -1484,7 +1482,7 @@ int QvkRegionChoise_wl::get_height_from_window()
  */
 int QvkRegionChoise_wl::get_XRecordArea()
 {
-    return ( frame_X + framePenWidth/2 + 1 ) * myDevicePixelRatio();
+    return ( frame_X + framePenWidth/2 ) * myDevicePixelRatio();
 }
 
 
@@ -1493,9 +1491,10 @@ int QvkRegionChoise_wl::get_XRecordArea()
  */
 int QvkRegionChoise_wl::get_YRecordArea()
 {
-    return ( frame_Y + framePenWidth/2 + 1 ) * myDevicePixelRatio();
+    return ( frame_Y + framePenWidth/2 ) * myDevicePixelRatio();
 }
 
+
 /**
  * Return width from record Area
  */
@@ -1504,6 +1503,7 @@ int QvkRegionChoise_wl::get_WidthRecordArea()
     return ( frame_Width - framePenWidth ) * myDevicePixelRatio();
 }
 
+
 /**
  * Return height from record area
  */
@@ -1523,3 +1523,34 @@ void QvkRegionChoise_wl::slot_areaReset()
     repaint();
     setMask( pixmap.mask() );
 }
+
+
+void QvkRegionChoise_wl::setX( int x )
+{
+    frame_X = x - framePenHalf;
+    repaint();
+    update();
+}
+
+
+void QvkRegionChoise_wl::setY( int y )
+{
+    frame_Y = y - framePenHalf;
+    repaint();
+    update();
+}
+
+
+void QvkRegionChoise_wl::setWidth( int width )
+{
+    frame_Width = width + framePenWidth;
+    repaint();
+    update();
+}
+
+void QvkRegionChoise_wl::setHeight( int height )
+{
+    frame_height = height + framePenWidth;
+    repaint();
+    update();
+}
